@@ -18,254 +18,175 @@ X-Windows (from the X-Windows C<rgb.txt> file).
 
 =head1 SEE ALSO
 
-C<Graphics::ColorNames>, C<rgb.txt>
+L<Graphics::ColorNames>, rgb.txt
 
 =head1 AUTHOR
 
-Robert Rothenberg <rrwo@cpan.org>
+Robert Rothenberg <rrwo at cpan.org>
 
-Steve Pomeroy <steve_x@earthling.net>  -- fixed the broken color definitions
+=head2 Acknowledgements
+
+Steve Pomeroy <steve_x at earthling.net> -- fixed the broken color definitions
+
+=head1 LICENSE
+
+Copyright (c) 2001-2008 Robert Rothenberg. All rights reserved.
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
 
 =cut
 
-require 5.005;
 use strict;
-# use warnings;
+use warnings;
 
-use vars qw( $VERSION );
-
-$VERSION = '1.03';
+our $VERSION = '2.11';
+#$VERSION = eval $VERSION;
 
 # Original name and colors (v1.01 and earlier) from Kevin J. Walsh,
 # http://eies.njit.edu/~walsh/rgb.html
 
 # Afterwards, XConsortium: rgb.txt,v 10.41 94/02/20 18:39:36 rws Exp
+# Verified with Xorg: rgb.txt,v 1.3 2000/08/17 19:54:00 cpqbld Exp
+
+# Duplicate namesiwth spaces were removed in v2.10.
 
 sub NamesRgbTable() {
   use integer;
   return {
     "snow"		    => 0xfffafa,
-    "ghost white"	    => 0xf8f8ff,
     "ghostwhite"	    => 0xf8f8ff,
-    "white smoke"	    => 0xf5f5f5,
     "whitesmoke"	    => 0xf5f5f5,
     "gainsboro"		    => 0xdcdcdc,
-    "floral white"	    => 0xfffaf0,
     "floralwhite"	    => 0xfffaf0,
-    "old lace"		    => 0xfdf5e6,
     "oldlace"		    => 0xfdf5e6,
     "linen"		    => 0xfaf0e6,
-    "antique white"	    => 0xfaebd7,
     "antiquewhite"	    => 0xfaebd7,
-    "papaya whip"	    => 0xffefd5,
     "papayawhip"	    => 0xffefd5,
-    "blanched almond"	    => 0xffebcd,
     "blanchedalmond"	    => 0xffebcd,
     "bisque"		    => 0xffe4c4,
-    "peach puff"	    => 0xffdab9,
     "peachpuff"		    => 0xffdab9,
-    "navajo white"	    => 0xffdead,
     "navajowhite"	    => 0xffdead,
     "moccasin"		    => 0xffe4b5,
     "cornsilk"		    => 0xfff8dc,
     "ivory"		    => 0xfffff0,
-    "lemon chiffon"	    => 0xfffacd,
     "lemonchiffon"	    => 0xfffacd,
     "seashell"		    => 0xfff5ee,
     "honeydew"		    => 0xf0fff0,
-    "mint cream"	    => 0xf5fffa,
     "mintcream"		    => 0xf5fffa,
     "azure"		    => 0xf0ffff,
-    "alice blue"	    => 0xf0f8ff,
     "aliceblue"		    => 0xf0f8ff,
     "lavender"		    => 0xe6e6fa,
-    "lavender blush"	    => 0xfff0f5,
     "lavenderblush"	    => 0xfff0f5,
-    "misty rose"	    => 0xffe4e1,
     "mistyrose"		    => 0xffe4e1,
     "white"		    => 0xffffff,
     "black"		    => 0x000000,
-    "dark slate gray"	    => 0x2f4f4f,
     "darkslategray"	    => 0x2f4f4f,
-    "dark slate grey"	    => 0x2f4f4f,
     "darkslategrey"	    => 0x2f4f4f,
-    "dim gray"		    => 0x696969,
     "dimgray"		    => 0x696969,
-    "dim grey"		    => 0x696969,
     "dimgrey"		    => 0x696969,
-    "slate gray"	    => 0x708090,
     "slategray"		    => 0x708090,
-    "slate grey"	    => 0x708090,
     "slategrey"		    => 0x708090,
-    "light slate gray"	    => 0x778899,
     "lightslategray"	    => 0x778899,
-    "light slate grey"	    => 0x778899,
     "lightslategrey"	    => 0x778899,
     "gray"		    => 0xbebebe,
     "grey"		    => 0xbebebe,
-    "light grey"	    => 0xd3d3d3,
     "lightgrey"		    => 0xd3d3d3,
-    "light gray"	    => 0xd3d3d3,
     "lightgray"		    => 0xd3d3d3,
-    "midnight blue"	    => 0x191970,
     "midnightblue"	    => 0x191970,
     "navy"		    => 0x000080,
-    "navy blue"		    => 0x000080,
     "navyblue"		    => 0x000080,
-    "cornflower blue"	    => 0x6495ed,
     "cornflowerblue"	    => 0x6495ed,
-    "dark slate blue"	    => 0x483d8b,
     "darkslateblue"	    => 0x483d8b,
-    "slate blue"	    => 0x6a5acd,
     "slateblue"		    => 0x6a5acd,
-    "medium slate blue"	    => 0x7b68ee,
     "mediumslateblue"	    => 0x7b68ee,
-    "light slate blue"	    => 0x8470ff,
     "lightslateblue"	    => 0x8470ff,
-    "medium blue"	    => 0x0000cd,
     "mediumblue"	    => 0x0000cd,
-    "royal blue"	    => 0x4169e1,
     "royalblue"		    => 0x4169e1,
     "blue"		    => 0x0000ff,
-    "dodger blue"	    => 0x1e90ff,
     "dodgerblue"	    => 0x1e90ff,
-    "deep sky blue"	    => 0x00bfff,
     "deepskyblue"	    => 0x00bfff,
-    "sky blue"		    => 0x87ceeb,
     "skyblue"		    => 0x87ceeb,
-    "light sky blue"	    => 0x87cefa,
     "lightskyblue"	    => 0x87cefa,
-    "steel blue"	    => 0x4682b4,
     "steelblue"		    => 0x4682b4,
-    "light steel blue"	    => 0xb0c4de,
     "lightsteelblue"	    => 0xb0c4de,
-    "light blue"	    => 0xadd8e6,
     "lightblue"		    => 0xadd8e6,
-    "powder blue"	    => 0xb0e0e6,
     "powderblue"	    => 0xb0e0e6,
-    "pale turquoise"	    => 0xafeeee,
     "paleturquoise"	    => 0xafeeee,
-    "dark turquoise"	    => 0x00ced1,
     "darkturquoise"	    => 0x00ced1,
-    "medium turquoise"	    => 0x48d1cc,
     "mediumturquoise"	    => 0x48d1cc,
     "turquoise"		    => 0x40e0d0,
     "cyan"		    => 0x00ffff,
-    "light cyan"	    => 0xe0ffff,
     "lightcyan"		    => 0xe0ffff,
-    "cadet blue"	    => 0x5f9ea0,
     "cadetblue"		    => 0x5f9ea0,
-    "medium aquamarine"	    => 0x66cdaa,
     "mediumaquamarine"	    => 0x66cdaa,
     "aquamarine"	    => 0x7fffd4,
-    "dark green"	    => 0x006400,
     "darkgreen"		    => 0x006400,
-    "dark olive green"	    => 0x556b2f,
     "darkolivegreen"	    => 0x556b2f,
-    "dark sea green"	    => 0x8fbc8f,
     "darkseagreen"	    => 0x8fbc8f,
-    "sea green"		    => 0x2e8b57,
     "seagreen"		    => 0x2e8b57,
-    "medium sea green"	    => 0x3cb371,
     "mediumseagreen"	    => 0x3cb371,
-    "light sea green"	    => 0x20b2aa,
     "lightseagreen"	    => 0x20b2aa,
-    "pale green"	    => 0x98fb98,
     "palegreen"		    => 0x98fb98,
-    "spring green"	    => 0x00ff7f,
     "springgreen"	    => 0x00ff7f,
-    "lawn green"	    => 0x7cfc00,
     "lawngreen"		    => 0x7cfc00,
     "green"		    => 0x00ff00,
     "chartreuse"	    => 0x7fff00,
-    "medium spring green"   => 0x00fa9a,
     "mediumspringgreen"	    => 0x00fa9a,
-    "green yellow"	    => 0xadff2f,
     "greenyellow"	    => 0xadff2f,
-    "lime green"	    => 0x32cd32,
     "limegreen"		    => 0x32cd32,
-    "yellow green"	    => 0x9acd32,
     "yellowgreen"	    => 0x9acd32,
-    "forest green"	    => 0x228b22,
     "forestgreen"	    => 0x228b22,
-    "olive drab"	    => 0x6b8e23,
     "olivedrab"		    => 0x6b8e23,
-    "dark khaki"	    => 0xbdb76b,
     "darkkhaki"		    => 0xbdb76b,
     "khaki"		    => 0xf0e68c,
-    "pale goldenrod"	    => 0xeee8aa,
     "palegoldenrod"	    => 0xeee8aa,
-    "light goldenrod yellow"=> 0xfafad2,
     "lightgoldenrodyellow"  => 0xfafad2,
-    "light yellow"	    => 0xffffe0,
     "lightyellow"	    => 0xffffe0,
     "yellow"		    => 0xffff00,
     "gold"		    => 0xffd700,
-    "light goldenrod"	    => 0xeedd82,
     "lightgoldenrod"	    => 0xeedd82,
     "goldenrod"		    => 0xdaa520,
-    "dark goldenrod"	    => 0xb8860b,
     "darkgoldenrod"	    => 0xb8860b,
-    "rosy brown"	    => 0xbc8f8f,
     "rosybrown"		    => 0xbc8f8f,
-    "indian red"	    => 0xcd5c5c,
     "indianred"		    => 0xcd5c5c,
-    "saddle brown"	    => 0x8b4513,
     "saddlebrown"	    => 0x8b4513,
     "sienna"		    => 0xa0522d,
     "peru"		    => 0xcd853f,
     "burlywood"		    => 0xdeb887,
     "beige"		    => 0xf5f5dc,
     "wheat"		    => 0xf5deb3,
-    "sandy brown"	    => 0xf4a460,
     "sandybrown"	    => 0xf4a460,
     "tan"		    => 0xd2b48c,
     "chocolate"		    => 0xd2691e,
     "firebrick"		    => 0xb22222,
     "brown"		    => 0xa52a2a,
-    "dark salmon"	    => 0xe9967a,
     "darksalmon"	    => 0xe9967a,
     "salmon"		    => 0xfa8072,
-    "light salmon"	    => 0xffa07a,
     "lightsalmon"	    => 0xffa07a,
     "orange"		    => 0xffa500,
-    "dark orange"	    => 0xff8c00,
     "darkorange"	    => 0xff8c00,
     "coral"		    => 0xff7f50,
-    "light coral"	    => 0xf08080,
     "lightcoral"	    => 0xf08080,
     "tomato"		    => 0xff6347,
-    "orange red"	    => 0xff4500,
     "orangered"		    => 0xff4500,
     "red"		    => 0xff0000,
-    "hot pink"		    => 0xff69b4,
     "hotpink"		    => 0xff69b4,
-    "deep pink"		    => 0xff1493,
     "deeppink"		    => 0xff1493,
     "pink"		    => 0xffc0cb,
-    "light pink"	    => 0xffb6c1,
     "lightpink"		    => 0xffb6c1,
-    "pale violet red"	    => 0xdb7093,
     "palevioletred"	    => 0xdb7093,
     "maroon"		    => 0xb03060,
-    "medium violet red"	    => 0xc71585,
     "mediumvioletred"	    => 0xc71585,
-    "violet red"	    => 0xd02090,
     "violetred"		    => 0xd02090,
     "magenta"		    => 0xff00ff,
     "violet"		    => 0xee82ee,
     "plum"		    => 0xdda0dd,
     "orchid"		    => 0xda70d6,
-    "medium orchid"	    => 0xba55d3,
     "mediumorchid"	    => 0xba55d3,
-    "dark orchid"	    => 0x9932cc,
     "darkorchid"	    => 0x9932cc,
-    "dark violet"	    => 0x9400d3,
     "darkviolet"	    => 0x9400d3,
-    "blue violet"	    => 0x8a2be2,
     "blueviolet"	    => 0x8a2be2,
     "purple"		    => 0xa020f0,
-    "medium purple"	    => 0x9370db,
     "mediumpurple"	    => 0x9370db,
     "thistle"		    => 0xd8bfd8,
     "snow1"		    => 0xfffafa,
@@ -356,6 +277,10 @@ sub NamesRgbTable() {
     "slategray2"	    => 0xb9d3ee,
     "slategray3"	    => 0x9fb6cd,
     "slategray4"	    => 0x6c7b8b,
+    "slategrey1"	    => 0xc6e2ff,
+    "slategrey2"	    => 0xb9d3ee,
+    "slategrey3"	    => 0x9fb6cd,
+    "slategrey4"	    => 0x6c7b8b,
     "lightsteelblue1"	    => 0xcae1ff,
     "lightsteelblue2"	    => 0xbcd2ee,
     "lightsteelblue3"	    => 0xa2b5cd,
@@ -388,6 +313,10 @@ sub NamesRgbTable() {
     "darkslategray2"	    => 0x8deeee,
     "darkslategray3"	    => 0x79cdcd,
     "darkslategray4"	    => 0x528b8b,
+    "darkslategrey1"	    => 0x97ffff,
+    "darkslategrey2"	    => 0x8deeee,
+    "darkslategrey3"	    => 0x79cdcd,
+    "darkslategrey4"	    => 0x528b8b,
     "aquamarine1"	    => 0x7fffd4,
     "aquamarine2"	    => 0x76eec6,
     "aquamarine3"	    => 0x66cdaa,
@@ -584,29 +513,29 @@ sub NamesRgbTable() {
     "gray1"		    => 0x030303,
     "gray2"		    => 0x050505,
     "gray3"		    => 0x080808,
-    "grey4"		    => 0x0a0a0a,
-    "grey5"		    => 0x0d0d0d,
-    "grey6"		    => 0x0f0f0f,
-    "grey7"		    => 0x121212,
-    "grey8"		    => 0x141414,
-    "grey9"		    => 0x171717,
-    "grey10"		    => 0x1a1a1a,
-    "grey11"		    => 0x1c1c1c,
-    "grey12"		    => 0x1f1f1f,
-    "grey13"		    => 0x212121,
-    "grey14"		    => 0x242424,
-    "grey15"		    => 0x262626,
-    "grey16"		    => 0x292929,
-    "grey17"		    => 0x2b2b2b,
-    "grey18"		    => 0x2e2e2e,
-    "grey19"		    => 0x303030,
-    "grey20"		    => 0x333333,
-    "grey21"		    => 0x363636,
-    "grey22"		    => 0x383838,
-    "grey23"		    => 0x3b3b3b,
-    "grey24"		    => 0x3d3d3d,
-    "grey25"		    => 0x404040,
-    "grey26"		    => 0x424242,
+    "gray4"		    => 0x0a0a0a,
+    "gray5"		    => 0x0d0d0d,
+    "gray6"		    => 0x0f0f0f,
+    "gray7"		    => 0x121212,
+    "gray8"		    => 0x141414,
+    "gray9"		    => 0x171717,
+    "gray10"		    => 0x1a1a1a,
+    "gray11"		    => 0x1c1c1c,
+    "gray12"		    => 0x1f1f1f,
+    "gray13"		    => 0x212121,
+    "gray14"		    => 0x242424,
+    "gray15"		    => 0x262626,
+    "gray16"		    => 0x292929,
+    "gray17"		    => 0x2b2b2b,
+    "gray18"		    => 0x2e2e2e,
+    "gray19"		    => 0x303030,
+    "gray20"		    => 0x333333,
+    "gray21"		    => 0x363636,
+    "gray22"		    => 0x383838,
+    "gray23"		    => 0x3b3b3b,
+    "gray24"		    => 0x3d3d3d,
+    "gray25"		    => 0x404040,
+    "gray26"		    => 0x424242,
     "gray27"		    => 0x454545,
     "gray28"		    => 0x474747,
     "gray29"		    => 0x4a4a4a,
@@ -653,7 +582,7 @@ sub NamesRgbTable() {
     "gray70"		    => 0xb3b3b3,
     "gray71"		    => 0xb5b5b5,
     "gray72"		    => 0xb8b8b8,
-    "grey73"		    => 0xbababa,
+    "gray73"		    => 0xbababa,
     "gray74"		    => 0xbdbdbd,
     "gray75"		    => 0xbfbfbf,
     "gray76"		    => 0xc2c2c2,
@@ -681,19 +610,113 @@ sub NamesRgbTable() {
     "gray98"		    => 0xfafafa,
     "gray99"		    => 0xfcfcfc,
     "gray100"		    => 0xffffff,
-    "dark grey"		    => 0xa9a9a9,
+    "grey0"		    => 0x000000,
+    "grey1"		    => 0x030303,
+    "grey2"		    => 0x050505,
+    "grey3"		    => 0x080808,
+    "grey4"		    => 0x0a0a0a,
+    "grey5"		    => 0x0d0d0d,
+    "grey6"		    => 0x0f0f0f,
+    "grey7"		    => 0x121212,
+    "grey8"		    => 0x141414,
+    "grey9"		    => 0x171717,
+    "grey10"		    => 0x1a1a1a,
+    "grey11"		    => 0x1c1c1c,
+    "grey12"		    => 0x1f1f1f,
+    "grey13"		    => 0x212121,
+    "grey14"		    => 0x242424,
+    "grey15"		    => 0x262626,
+    "grey16"		    => 0x292929,
+    "grey17"		    => 0x2b2b2b,
+    "grey18"		    => 0x2e2e2e,
+    "grey19"		    => 0x303030,
+    "grey20"		    => 0x333333,
+    "grey21"		    => 0x363636,
+    "grey22"		    => 0x383838,
+    "grey23"		    => 0x3b3b3b,
+    "grey24"		    => 0x3d3d3d,
+    "grey25"		    => 0x404040,
+    "grey26"		    => 0x424242,
+    "grey27"		    => 0x454545,
+    "grey28"		    => 0x474747,
+    "grey29"		    => 0x4a4a4a,
+    "grey30"		    => 0x4d4d4d,
+    "grey31"		    => 0x4f4f4f,
+    "grey32"		    => 0x525252,
+    "grey33"		    => 0x545454,
+    "grey34"		    => 0x575757,
+    "grey35"		    => 0x595959,
+    "grey36"		    => 0x5c5c5c,
+    "grey37"		    => 0x5e5e5e,
+    "grey38"		    => 0x616161,
+    "grey39"		    => 0x636363,
+    "grey40"		    => 0x666666,
+    "grey41"		    => 0x696969,
+    "grey42"		    => 0x6b6b6b,
+    "grey43"		    => 0x6e6e6e,
+    "grey44"		    => 0x707070,
+    "grey45"		    => 0x737373,
+    "grey46"		    => 0x757575,
+    "grey47"		    => 0x787878,
+    "grey48"		    => 0x7a7a7a,
+    "grey49"		    => 0x7d7d7d,
+    "grey50"		    => 0x7f7f7f,
+    "grey51"		    => 0x828282,
+    "grey52"		    => 0x858585,
+    "grey53"		    => 0x878787,
+    "grey54"		    => 0x8a8a8a,
+    "grey55"		    => 0x8c8c8c,
+    "grey56"		    => 0x8f8f8f,
+    "grey57"		    => 0x919191,
+    "grey58"		    => 0x949494,
+    "grey59"		    => 0x969696,
+    "grey60"		    => 0x999999,
+    "grey61"		    => 0x9c9c9c,
+    "grey62"		    => 0x9e9e9e,
+    "grey63"		    => 0xa1a1a1,
+    "grey64"		    => 0xa3a3a3,
+    "grey65"		    => 0xa6a6a6,
+    "grey66"		    => 0xa8a8a8,
+    "grey67"		    => 0xababab,
+    "grey68"		    => 0xadadad,
+    "grey69"		    => 0xb0b0b0,
+    "grey70"		    => 0xb3b3b3,
+    "grey71"		    => 0xb5b5b5,
+    "grey72"		    => 0xb8b8b8,
+    "grey73"		    => 0xbababa,
+    "grey74"		    => 0xbdbdbd,
+    "grey75"		    => 0xbfbfbf,
+    "grey76"		    => 0xc2c2c2,
+    "grey77"		    => 0xc4c4c4,
+    "grey78"		    => 0xc7c7c7,
+    "grey79"		    => 0xc9c9c9,
+    "grey80"		    => 0xcccccc,
+    "grey81"		    => 0xcfcfcf,
+    "grey82"		    => 0xd1d1d1,
+    "grey83"		    => 0xd4d4d4,
+    "grey84"		    => 0xd6d6d6,
+    "grey85"		    => 0xd9d9d9,
+    "grey86"		    => 0xdbdbdb,
+    "grey87"		    => 0xdedede,
+    "grey88"		    => 0xe0e0e0,
+    "grey89"		    => 0xe3e3e3,
+    "grey90"		    => 0xe5e5e5,
+    "grey91"		    => 0xe8e8e8,
+    "grey92"		    => 0xebebeb,
+    "grey93"		    => 0xededed,
+    "grey94"		    => 0xf0f0f0,
+    "grey95"		    => 0xf2f2f2,
+    "grey96"		    => 0xf5f5f5,
+    "grey97"		    => 0xf7f7f7,
+    "grey98"		    => 0xfafafa,
+    "grey99"		    => 0xfcfcfc,
+    "grey100"		    => 0xffffff,
     "darkgrey"		    => 0xa9a9a9,
-    "dark gray"		    => 0xa9a9a9,
     "darkgray"		    => 0xa9a9a9,
-    "dark blue"		    => 0x00008b,
     "darkblue"		    => 0x00008b,
-    "dark cyan"		    => 0x008b8b,
     "darkcyan"		    => 0x008b8b,
-    "dark magenta"	    => 0x8b008b,
     "darkmagenta"	    => 0x8b008b,
-    "dark red"		    => 0x8b0000,
     "darkred"		    => 0x8b0000,
-    "light green"	    => 0x90ee90,
     "lightgreen"	    => 0x90ee90,
   };
 }
@@ -701,3 +724,4 @@ sub NamesRgbTable() {
 1;
 
 __END__
+
